create_aliases: Create aliases for food names in the yummm market

Description Usage Arguments

View source: R/market.R

Description

Create alias(es) for food names in the yummm market, so that the correct color is printed when a user calls an alias instead of the name under which the food is stored in the yummm market. NB: This function is only used internally.

Usage

1

Arguments

food

Character. Food as stored in the yummm market.

alias

Character vector. Alias(es) of food.


StefanVriend/yummm documentation built on Aug. 22, 2020, 2:13 a.m.