smoothie: Delicious smoothies to decorate your graphics

Description Usage Arguments Value See Also Examples

View source: R/smoothie.R

Description

Use your favorite smoothie to color your graphics and texts.

Usage

1
2
3
4
5
smoothie(
  food,
  shade = rep("01", length(food)),
  alpha = rep(1/length(food), length(food))
)

Arguments

food

Character vector. Ingredients of your smoothie.

shade

Character vector. Shade of your food of choice. Possible id's: "01":"10". Default is set to "01".

alpha

Numeric vector. Opacity levels of ingredients of your smoothie. Each value in [0,1]. Default is 1/length(food).

Value

A character string (in hexadecimal format) corresponding to the smoothie created with the food of your choice.

See Also

yummm

Examples

1
2
3
smoothie(c("banana", "kiwi"))

smoothie(c("banana", "kiwi"), alpha=c(0.4, 0.6))

StefanVriend/yummm documentation built on Aug. 22, 2020, 2:13 a.m.