Description Usage Arguments Details Value See Also Examples
Use your favorite food to color your graphics and texts.
1 | yummm(food, shade)
|
food |
Character vector. Food of your choice. |
shade |
Character vector. Shade of your food of choice. Possible id's: "01":"10". |
Use yummm_palette to visualize all the shades of the food of your choice.
A character string (in hexadecimal format) corresponding to the food of your choice.
1 | yummm(food = "banana", shade = "05")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.