yummm_aliases: Aliases for food names

Description Usage Format

Description

A list with aliases for food names, so that the correct color is printed when a user calls an alias instead of the name under which the food is stored in the yummm market.

Usage

1

Format

A list of food names, each item is a character vector of aliases.


StefanVriend/yummm documentation built on Aug. 22, 2020, 2:13 a.m.