yummm_market: The yummm market: a table of food and palettes

Description Usage Format

Description

A list with all food and palettes in yummm. The market is filled using fill_market.

Usage

1

Format

A list of food names, each item is a dataframe of 10 rows and 2 columns:

Color

Character. Color in hexadecimal format.

Shade

Character. Shade ID of each color ("01"–"10").


StefanVriend/yummm documentation built on Aug. 22, 2020, 2:13 a.m.