Create alias(es) for food names in the yummm market, so that the correct color is printed when a user calls an alias instead of the name under which the food is stored in the yummm market. NB: This function is only used internally.
1 | create_aliases(food, alias)
|
food |
Character. Food as stored in the yummm market. |
alias |
Character vector. Alias(es) of food. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.