Description Usage Arguments Value See Also Examples
Use your favorite smoothie to color your graphics and texts.
1 2 3 4 5 |
food |
Character vector. Ingredients of your smoothie. |
shade |
Character vector. Shade of your food of choice. Possible id's: "01":"10". Default is set to "01". |
alpha |
Numeric vector. Opacity levels of ingredients of your smoothie. Each value in [0,1]. Default is |
A character string (in hexadecimal format) corresponding to the smoothie created with the food of your choice.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.