A list with aliases for food names, so that the correct color is printed when a user calls an alias instead of the name under which the food is stored in the yummm market.
1 |
A list of food names, each item is a character vector of aliases.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.