A list with all food and palettes in yummm. The market is filled using fill_market.
1 |
A list of food names, each item is a dataframe of 10 rows and 2 columns:
Character. Color in hexadecimal format.
Character. Shade ID of each color ("01"–"10").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.